@@ -100,9 +100,11 @@ functionField name value = Context $ \k i -> case words k of
 mapContext :: (String -> String) -> Context a -> Context a
 mapContext f (Context c) = Context $ \k i -> do
     fld <- c k i
-    return $ case fld of
-        StringField str  -> StringField (f str)
-        ListField ctx is -> ListField ctx is
+    case fld of
+        StringField str -> return $ StringField (f str)
+        ListField _ _   -> fail $
+            "Hakyll.Web.Template.Context.mapContext: " ++
+            "can't map over a ListField!"
 
 
 --------------------------------------------------------------------------------
@@ -128,7 +130,7 @@ bodyField key = field key $ return . itemBody
 
 --------------------------------------------------------------------------------
 -- | Map any field to its metadata value, if present
-metadataField :: Context String
+metadataField :: Context a
 metadataField = Context $ \k i -> do
     value <- getMetadataField (itemIdentifier i) k
     maybe empty (return . StringField) value
