@@ -26,6 +26,7 @@ tests = testGroup "Hakyll.Core.Store.Tests"
     [ testProperty "simple get . set"     simpleSetGet
     , testProperty "persistent get . set" persistentSetGet
     , testCase     "WrongType get . set"  wrongType
+    , testCase     "isMembertest . set"   isMembertest
     ]
 
 
@@ -68,3 +69,15 @@ wrongType = do
             t == typeOf (undefined :: String)
         _                   -> False
     cleanTestEnv
+
+
+--------------------------------------------------------------------------------
+isMembertest :: H.Assertion
+isMembertest = do
+    store <- newTestStore
+    Store.set store ["foo", "bar"] ("qux" :: String)
+    good <- Store.isMember store ["foo", "bar"]
+    bad  <- Store.isMember store ["foo", "baz"]
+    H.assert good
+    H.assert (not bad)
+    cleanTestEnv
