@@ -51,4 +51,9 @@ testContextDone :: Store -> Provider -> Identifier -> String
 testContextDone store provider identifier key context =
     testCompilerDone store provider identifier $ do
         item <- getResourceBody
-        unContext context key item
+        cf   <- unContext context key item
+        case cf of
+            StringField str -> return str
+            ListField _ _   -> error $
+                "Hakyll.Web.Template.Context.Tests.testContextDone: " ++
+                "Didn't expect ListField"
